shill: Rename *ProxyListener to *ProxyDelegate to conform to coding style.

Coding style requires multiple inheritance only from pure interfaces tagged with
the Interface suffix. Chromium style allows Delegate instead of Interface.

After this change, a *ProxyInterface class is the RPC proxy abstraction provided
for unit test purposes, and a *ProxyDelegate can be inherited and implemented by
proxy clients to catch RPC callbacks. For example, ModemProxyInterface is the
interface to a ModemManager.Modem service, implemented concretely for dbus-c++
by the ModemProxy class; all callbacks get rerouted by ModemProxy to a
ModemProxyDelegate.

BUG=chromium-os:19115
TEST=unit tests

Change-Id: I75c4c5c1f256b338e665e77f58972ab75f39490e
Reviewed-on: http://gerrit.chromium.org/gerrit/10562
Tested-by: Darin Petkov <petkov@chromium.org>
Reviewed-by: Paul Stewart <pstew@chromium.org>
Commit-Ready: Darin Petkov <petkov@chromium.org>
diff --git a/modem.h b/modem.h
index 766e7d5..dac7409 100644
--- a/modem.h
+++ b/modem.h
@@ -24,7 +24,7 @@
 
 // Handles an instance of ModemManager.Modem and an instance of a Cellular
 // device.
-class Modem : public DBusPropertiesProxyListener {
+class Modem : public DBusPropertiesProxyDelegate {
  public:
   // |owner| is the ModemManager DBus service owner (e.g., ":1.17"). |path| is
   // the ModemManager.Modem DBus object path (e.g.,
@@ -63,7 +63,7 @@
   // properties are invalid.
   void CreateCellularDevice(const DBusPropertiesMap &properties);
 
   // Signal callbacks inherited from DBusPropertiesProxyListener.
   virtual void OnDBusPropertiesChanged(
       const std::string &interface,
       const DBusPropertiesMap &changed_properties,
@@ -63,7 +63,7 @@
   void CreateCellularDevice(const DBusPropertiesMap &properties);
 
-  // Signal callbacks inherited from DBusPropertiesProxyListener.
+  // Signal callbacks inherited from DBusPropertiesProxyDelegate.
   virtual void OnDBusPropertiesChanged(
       const std::string &interface,